multidim.covertree.CoverTree.plot — GDA Toolbox v1.0 Manual

# multidim.covertree.CoverTree.plot

`CoverTree.` `plot`(canvas, **kwargs)

  Interactive plot of a CoverTree, with dynamic computation of levels.

  Parameters: | canvas : `bokeh.plotting.figure.Figure` as obtained from `canvas = bokeh.plotting.figure()` Other parameters are fed to :func:`CoverLevel.plot`

#### Previous topic

multidim.covertree.CoverTree.next

#### Next topic

multidim.covertree.CoverTree.plot_tree